<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';

const formTable = ref(null);
const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;
    post(isSave.value ? '/api/waveDetl/save' : '/api/waveDetl/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(isSave.value ? formatMessage('page.add.success', '新增成功') : formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
        nextTick(() => {
            formTable.value.resetFields()
        })
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const waveQueryList = ref(null); 
waveQuery();
function waveQuery() { 
    postForm('/api/wave/query', {}).then(resp => { 
        let result = resp.data;
        waveQueryList.value = result.data;
    })
}
const orderQueryList = ref(null); 
orderQuery();
function orderQuery() { 
    postForm('/api/order/query', {}).then(resp => { 
        let result = resp.data;
        orderQueryList.value = result.data;
    })
}
const userQueryList = ref(null); 
userQuery();
function userQuery() { 
    postForm('/api/user/query', {}).then(resp => { 
        let result = resp.data;
        userQueryList.value = result.data;
    })
}


defineExpose({
    open,
    formData,
    initFormData,
    isSave,
})

</script>

<script>
export default {
    name: '波次明细管理-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" ref="formTable" name="formTable" :label-col="{ span: 8 }" :wrapper-col="{ span: 16 }"
                style="display: flex;justify-content: space-between;flex-wrap: wrap;" autocomplete="off"
                @finish="onFinish" @finishFailed="onFinishFailed">
                    <a-form-item 
                      :label="formatMessage('db.man_wave_detl.wave_id', '波次ID') " 
                      name="waveId" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.waveId" 
                        :placeholder="formatMessage('common.select', '请选择')" 
                        style="width: 100%" 
                        show-search 
                        :options="waveQueryList" 
                        optionFilterProp="label" 
                        optionLabelProp="label" 
                     > 
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_wave_detl.wave_no', '波次号') " 
                      name="waveNo" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.waveNo" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_wave_detl.order_id', '订单ID') " 
                      name="orderId" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.orderId" 
                        :placeholder="formatMessage('common.select', '请选择')" 
                        style="width: 100%" 
                        show-search 
                        :options="orderQueryList" 
                        optionFilterProp="label" 
                        optionLabelProp="label" 
                     > 
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_wave_detl.order_no', '订单号') " 
                      name="orderNo" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.orderNo" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_wave_detl.status', '状态') " 
                      name="status" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.status" 
                        :options="[
                                { label: '正常', value: 1 },
                                { label: '禁用', value: 0 },
                            ]"
                        >
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_wave_detl.create_time', '添加时间') " 
                      name="createTime" 
                      style="width: 250px;" 
                            >
                    <a-date-picker 
                        v-model:value="formData.createTime" 
                        show-time 
                        format="YYYY-MM-DD HH:mm:ss" 
                        value-format="YYYY-MM-DD HH:mm:ss" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_wave_detl.create_by', '添加人员') " 
                      name="createBy" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.createBy" 
                        :placeholder="formatMessage('common.select', '请选择')" 
                        style="width: 100%" 
                        show-search 
                        :options="userQueryList" 
                        optionFilterProp="label" 
                        optionLabelProp="label" 
                     > 
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_wave_detl.update_time', '修改时间') " 
                      name="updateTime" 
                      style="width: 250px;" 
                            >
                    <a-date-picker 
                        v-model:value="formData.updateTime" 
                        show-time 
                        format="YYYY-MM-DD HH:mm:ss" 
                        value-format="YYYY-MM-DD HH:mm:ss" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_wave_detl.update_by', '修改人员') " 
                      name="updateBy" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.updateBy" 
                        :placeholder="formatMessage('common.select', '请选择')" 
                        style="width: 100%" 
                        show-search 
                        :options="userQueryList" 
                        optionFilterProp="label" 
                        optionLabelProp="label" 
                     > 
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_wave_detl.memo', '备注') " 
                      name="memo" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.memo" 
                     /> 
                        </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
